aboutsummaryrefslogtreecommitdiff
path: root/install.sh
diff options
context:
space:
mode:
authorCédric Bonhomme <cedric@cedricbonhomme.org>2015-11-26 18:47:10 +0100
committerCédric Bonhomme <cedric@cedricbonhomme.org>2015-11-26 18:47:10 +0100
commitd8d46c33dc766b904124eaad2dee5d7964711060 (patch)
treef549b7cd3acfa99425d4c7248e8b431de695bc7f /install.sh
parentBug fix in the crawler when logging the creation of articles. (diff)
downloadnewspipe-d8d46c33dc766b904124eaad2dee5d7964711060.tar.gz
newspipe-d8d46c33dc766b904124eaad2dee5d7964711060.tar.bz2
newspipe-d8d46c33dc766b904124eaad2dee5d7964711060.zip
More refactorization.
Diffstat (limited to 'install.sh')
-rwxr-xr-xinstall.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/install.sh b/install.sh
index 19f53b61..7e5c68ed 100755
--- a/install.sh
+++ b/install.sh
@@ -1,7 +1,7 @@
#! /usr/bin/env bash
#
# This script install all dependencies and configure pyAggr3g470r
# for Python 3.
#
@@ -37,7 +37,7 @@ elif [ "$1" == sqlite ]; then
sudo pip$PYTHON_VERSION install pysqlite # not working with Python 3!
# Add configuration lines for SQLite
echo '[database]' >> conf/conf.cfg
- echo 'database_url = sqlite+pysqlite:///pyAggr3g470r.db' >> conf/conf.cfg
+ echo 'database_url = sqlite+pysqlite:///jarr.db' >> conf/conf.cfg
fi
python$PYTHON_VERSION manager.py db_empty
bgstack15
@@ -1,7 +1,7 @@
#! /usr/bin/env bash
#
-# This script install all dependencies and configure pyAggr3g470r
+# This script install all dependencies and configure JARR
# for Python 3.
#